@@ -26,7 +26,7 @@ MeasureBIC = R6Class("MeasureBIC",
         id = "bic",
         task_type = NA_character_,
         properties = c("na_score", "requires_learner", "requires_model"),
-        predict_type = "response",
+        predict_type = NA_character_,
         minimize = TRUE,
         label = "Bayesian Information Criterion",
         man = "mlr3::mlr_measures_bic"
