@@ -89,4 +89,4 @@ ResamplingBootstrap = R6Class("ResamplingBootstrap", inherit = Resampling,
 )
 
 #' @include mlr_resamplings.R
-mlr_resamplings$add("bootstrap", ResamplingBootstrap)
+mlr_resamplings$add("bootstrap", function() ResamplingBootstrap$new())
