@@ -17,10 +17,11 @@
 #' See [mlr3misc::Dictionary].
 #'
 #' @section S3 methods:
-#' * `as.data.table(dict)`\cr
+#' * `as.data.table(dict, ..., objects = FALSE)`\cr
 #'   [mlr3misc::Dictionary] -> [data.table::data.table()]\cr
-#'   Returns a [data.table::data.table()] with fields "key", "task_type", "predict_type",
-#'   and "packages" as columns.
+#'   Returns a [data.table::data.table()] with fields "key", "label", "task_type", "packages",
+#'   "predict_type", and "task_properties" as columns.
+#'   If `objects` is set to `TRUE`, the constructed objects are returned in the list column named `object`.
 #'
 #' @family Dictionary
 #' @family Measure
@@ -39,16 +40,16 @@ mlr_measures = R6Class("DictionaryMeasure",
 )$new()
 
 #' @export
-as.data.table.DictionaryMeasure = function(x, ...) {
+as.data.table.DictionaryMeasure = function(x, ..., objects = FALSE) {
+  assert_flag(objects)
+
   setkeyv(map_dtr(x$keys(), function(key) {
     m = withCallingHandlers(x$get(key),
       packageNotFoundWarning = function(w) invokeRestart("muffleWarning"))
-    list(
-      key = key,
-      task_type = m$task_type,
-      packages = list(m$packages),
-      predict_type = m$predict_type,
-      task_properties = list(m$task_properties)
+    insert_named(
+      list(key = key, label = m$label, task_type = m$task_type, packages = list(m$packages), predict_type = m$predict_type,
+        task_properties = list(m$task_properties)),
+      if (objects) list(object = list(m))
     )
-  }), "key")[]
+  }, .fill = TRUE), "key")[]
 }
