@@ -260,9 +260,13 @@ workhorse = function(iteration, task, learner, resampling, param_values = NULL,
   # reduce data.table and blas threads to 1
   if (!is_sequential) {
     setDTthreads(1, restore_after_fork = TRUE)
-    old_blas_threads = blas_get_num_procs()
-    on.exit(blas_set_num_threads(old_blas_threads), add = TRUE)
-    blas_set_num_threads(1)
+
+    # RhpcBLASctl is licensed under AGPL and therefore should be in suggest #1023
+    if (require_namespaces("RhpcBLASctl", quietly = TRUE)) {
+      old_blas_threads = RhpcBLASctl::blas_get_num_procs()
+      on.exit(RhpcBLASctl::blas_set_num_threads(old_blas_threads), add = TRUE)
+      RhpcBLASctl::blas_set_num_threads(1)
+    }
   }
   # restore logger thresholds
   for (package in names(lgr_threshold)) {
